@@ -2,7 +2,7 @@ package MojoX::UserAgent::Throttler;
 
 use Mojo::Base -strict;
 
-our $VERSION = 'v1.0.1';
+our $VERSION = 'v1.0.2';
 
 use Mojo::UserAgent;
 use Mojo::Util qw( monkey_patch );
@@ -89,7 +89,7 @@ sub _client_close {
     if ($close && !$res->code && !$res->error) {
         $res->error({message => 'Premature connection close'});
     }
-    elsif ($res->is_status_class(400) || $res->is_status_class(500)) {
+    elsif ($res->is_error) {
         $res->error({message => $res->message, code => $res->code});
     }
 
@@ -109,7 +109,7 @@ MojoX::UserAgent::Throttler - add throttling support to Mojo::UserAgent
 
 =head1 VERSION
 
-This document describes MojoX::UserAgent::Throttler version v1.0.1
+This document describes MojoX::UserAgent::Throttler version v1.0.2
 
 
 =head1 SYNOPSIS
